### Name: moprofile
### Title: Produce Marginal Ordinal Time Profiles for Plotting
### Aliases: moprofile.default moprofile.lcr moprofile.kalordinal
###   plot.moprofile
### Keywords: hplot

### ** Examples

library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

# Time-constant and time-varying covariate with a frailty dependence.
z <- kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
            ptvc=c(4.43357,-0.03128,-0.62602,-0.37679,-0.32969,-0.17013,
                   -0.12209,-0.09095),pinit=0.1196,dep="frailty")

# Cumulative probability profiles.
par(mfrow=c(2,2))
plot(moprofile(z,"cum"),nind=1)
plot(moprofile(z,"cum"),nind=117)
plot(moprofile(z,"cum"),nind=c(1000,3000),add=T)
par(mfrow=c(1,1))

# Highest probability profiles.
par(mfrow=c(2,2))
plot(moprofile(z,"prob"),nind=2000)
plot(moprofile(z,"prob"),nind=3001)
plot(moprofile(z,"prob"),nind=c(3506,3521))
plot(moprofile(z,"prob"),nind=400)
par(mfrow=c(1,1))

rm(w,z)

#
# Ordinal data
#
data(obese)

resp <- cbind(codes(obese[,1])-1,codes(obese[,2])-1)
freq <- obese[,4]

age <- obese[,3]

rm(obese)

y <- restovec(resp,times=1:2,weights=freq,type="ordinal")

tcc <- tcctomat(age,name="age")

tvc <- tvctomat(matrix(times(y)^2,ncol=2),name="times2")

w <- rmna(y,ccov=tcc,tvcov=tvc)

rm(resp,freq,age,y,tcc,tvc)

z <- lcr(w,mu=~age*times+times2)

# Cumulative probability profiles.
par(mfrow=c(2,2))
plot(moprofile(z,"cum"),nind=1)
plot(moprofile(z,"cum"),nind=4)
plot(moprofile(z,"cum"),nind=8:9,add=T)
par(mfrow=c(1,1))

# Highest probability profiles.
par(mfrow=c(2,2))
plot(moprofile(z,"prob"),nind=1)
plot(moprofile(z,"prob"),nind=4)
plot(moprofile(z,"prob"),nind=c(8,9))
plot(moprofile(z,"prob"),nind=16)
par(mfrow=c(1,1))

rm(w,z)



