### Name: poprofile
### Title: Produce Predicted Ordinal Time Profiles for Plotting
### Aliases: poprofile.default plot.poprofile
### Keywords: hplot

### ** Examples

library(ordinal)

#
# Binary data
#
data(cardiac.indiv)

y <- restovec(cardiac.indiv[,1:4],type="ordinal")

cov <- tcctomat(as.matrix(cardiac.indiv[,5:10]))

w <- rmna(y,ccov=cov)

rm(cardiac.indiv,y,cov)

# Time-constant and time-varying covariate with a frailty dependence.
z <- kalord(w,distribution="binary",mu=~age+ren+cop+dia+sex+pmi+times,
            ptvc=c(4.43357,-0.03128,-0.62602,-0.37679,-0.32969,-0.17013,
                   -0.12209,-0.09095),pinit=0.1196,dep="frailty")
ren <- rep(0,4)
cop <- rep(0,4)
dia <- rep(0,4)
sex <- rep(0,4)
pmi <- rep(0,4)
times <- 1:4

# Predicted highest probability profiles.
par(mfrow=c(2,2))
for(i in c(1,25,50,80)) {
  age <- rep(i,4)
  mu <- finterp(attr(z$mu,"formula"),.intercep=F)
  prof <- poprofile(mu,pint=4.43362,preg=c(4.43362,-0.03128,-0.62602,-0.37679,
                                           -0.32969,-0.17013,-0.12209,-0.09095),
                    pinit=NULL,times=times,dist="binary",curve="prob")
  plot(prof,main=paste("Age: ",i,sep=""))
}
par(mfrow=c(1,1))

# Predicted cumulative probability profiles.
par(mfrow=c(2,2))
for(i in c(1,25,50,80)) {
  age <- rep(i,4)
  mu <- finterp(attr(z$mu,"formula"),.intercep=F)
  prof <- poprofile(mu,pint=4.43362,preg=c(-0.03128,-0.62602,-0.37679,-0.32969,
                                           -0.17013,-0.12209,-0.09095),
                    pinit=NULL,times=times,dist="binary",curve="cum")
  plot(prof,main=paste("Age: ",i,sep=""))
}
par(mfrow=c(1,1))

rm(w,z,ren,cop,dia,sex,pmi,times,mu,i,age,prof)

#
# Ordinal data
#
data(tmi2)

y <- restovec(tmi2[,1:4],type="ordinal")

cov <- tcctomat(tmi2[,5],name="distance")

w <- rmna(y,ccov=cov)

rm(tmi2,y,cov)

# Proportional-odds model with time-constant covariate with a Markov dependence.
z <- kalord(w,distribution="proportional-odds",ccov=~distance,
            preg=c(-1.89,11.652,-0.199),pinit=3.111,pdep=0.217,dep="Markov")

mu <- function(p) rep(p[1]*distance,4)

# Predicted highest probability profiles.
par(mfrow=c(1,2))
for(distance in 1:2)
  plot(poprofile(mu,pint=c(-1.89,11.655),preg=-0.199,pinit=NULL,times=1:4,
                 dist="prop",curve="prob"),main=paste("Distance: ",distance,sep=""))
par(mfrow=c(1,1))

# Predicted cumulative probability profiles.
par(mfrow=c(1,2))
for(distance in 1:2)
  plot(poprofile(mu,pint=c(-1.89,11.655),preg=-0.199,pinit=NULL,times=1:4,
                 dist="prop",curve="cum"),main=paste("Distance: ",distance,sep=""))
par(mfrow=c(1,1))

rm(w,z,mu,distance)



